HeatshrinkPy
============

Compression using the `Heatshrink algorithm
<https://github.com/atomicobject/heatshrink>`__ in Python 3.

This library is a pure Python rewrite and a drop-in replacenment of `heatshrink2 <https://github.com/eerimoq/pyheatshrink>`__ library.

It is significantly slower than the native one. It can be used as a fallback if building a native extension is not an
option.

Installation
------------

From PyPI:

.. code-block::

   $ pip install heatshrinkpy

Usage
-----

Please refer to the `heatshrink2 <https://github.com/eerimoq/pyheatshrink>`__ library for usage and documentation -
just replace heatshrink2 with heatshrinkpy where applicable.

License
-------

ISC license
